# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.scheduled_report_subscription_api import ScheduledReportSubscriptionApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestScheduledReportSubscriptionApi(unittest.TestCase):
    """ScheduledReportSubscriptionApi unit test stubs"""

    def setUp(self):
        self.api = ScheduledReportSubscriptionApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_scheduled_report_subscription(self):
        """Test case for create_scheduled_report_subscription

        Creates a scheduled report subscription  # noqa: E501
        """
        pass

    def test_delete_scheduled_report_subscription(self):
        """Test case for delete_scheduled_report_subscription

        Deletes a scheduled report subscription  # noqa: E501
        """
        pass

    def test_get_scheduled_report_subscription(self):
        """Test case for get_scheduled_report_subscription

        Gets a single scheduled report subscription  # noqa: E501
        """
        pass

    def test_get_scheduled_report_subscriptions(self):
        """Test case for get_scheduled_report_subscriptions

        Get multiple scheduled report subscriptions  # noqa: E501
        """
        pass

    def test_update_scheduled_report_subscription(self):
        """Test case for update_scheduled_report_subscription

        Updates a scheduled report subscription  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class BearingResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'manufacturer': 'str',
        'roller_count': 'int',
        'ftf': 'float',
        'bsf': 'float',
        'bpfo': 'float',
        'bpfi': 'float'
    }

    attribute_map = {
        'id': 'Id',
        'name': 'Name',
        'manufacturer': 'Manufacturer',
        'roller_count': 'RollerCount',
        'ftf': 'Ftf',
        'bsf': 'Bsf',
        'bpfo': 'Bpfo',
        'bpfi': 'Bpfi'
    }

    def __init__(self, id=None, name=None, manufacturer=None, roller_count=None, ftf=None, bsf=None, bpfo=None, bpfi=None):  # noqa: E501
        """BearingResponse - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._name = None
        self._manufacturer = None
        self._roller_count = None
        self._ftf = None
        self._bsf = None
        self._bpfo = None
        self._bpfi = None
        self.discriminator = None
        self.id = id
        self.name = name
        self.manufacturer = manufacturer
        self.roller_count = roller_count
        self.ftf = ftf
        if bsf is not None:
            self.bsf = bsf
        self.bpfo = bpfo
        self.bpfi = bpfi

    @property
    def id(self):
        """Gets the id of this BearingResponse.  # noqa: E501


        :return: The id of this BearingResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BearingResponse.


        :param id: The id of this BearingResponse.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this BearingResponse.  # noqa: E501


        :return: The name of this BearingResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BearingResponse.


        :param name: The name of this BearingResponse.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def manufacturer(self):
        """Gets the manufacturer of this BearingResponse.  # noqa: E501


        :return: The manufacturer of this BearingResponse.  # noqa: E501
        :rtype: str
        """
        return self._manufacturer

    @manufacturer.setter
    def manufacturer(self, manufacturer):
        """Sets the manufacturer of this BearingResponse.


        :param manufacturer: The manufacturer of this BearingResponse.  # noqa: E501
        :type: str
        """
        if manufacturer is None:
            raise ValueError("Invalid value for `manufacturer`, must not be `None`")  # noqa: E501

        self._manufacturer = manufacturer

    @property
    def roller_count(self):
        """Gets the roller_count of this BearingResponse.  # noqa: E501


        :return: The roller_count of this BearingResponse.  # noqa: E501
        :rtype: int
        """
        return self._roller_count

    @roller_count.setter
    def roller_count(self, roller_count):
        """Sets the roller_count of this BearingResponse.


        :param roller_count: The roller_count of this BearingResponse.  # noqa: E501
        :type: int
        """
        if roller_count is None:
            raise ValueError("Invalid value for `roller_count`, must not be `None`")  # noqa: E501

        self._roller_count = roller_count

    @property
    def ftf(self):
        """Gets the ftf of this BearingResponse.  # noqa: E501


        :return: The ftf of this BearingResponse.  # noqa: E501
        :rtype: float
        """
        return self._ftf

    @ftf.setter
    def ftf(self, ftf):
        """Sets the ftf of this BearingResponse.


        :param ftf: The ftf of this BearingResponse.  # noqa: E501
        :type: float
        """
        if ftf is None:
            raise ValueError("Invalid value for `ftf`, must not be `None`")  # noqa: E501

        self._ftf = ftf

    @property
    def bsf(self):
        """Gets the bsf of this BearingResponse.  # noqa: E501


        :return: The bsf of this BearingResponse.  # noqa: E501
        :rtype: float
        """
        return self._bsf

    @bsf.setter
    def bsf(self, bsf):
        """Sets the bsf of this BearingResponse.


        :param bsf: The bsf of this BearingResponse.  # noqa: E501
        :type: float
        """

        self._bsf = bsf

    @property
    def bpfo(self):
        """Gets the bpfo of this BearingResponse.  # noqa: E501


        :return: The bpfo of this BearingResponse.  # noqa: E501
        :rtype: float
        """
        return self._bpfo

    @bpfo.setter
    def bpfo(self, bpfo):
        """Sets the bpfo of this BearingResponse.


        :param bpfo: The bpfo of this BearingResponse.  # noqa: E501
        :type: float
        """
        if bpfo is None:
            raise ValueError("Invalid value for `bpfo`, must not be `None`")  # noqa: E501

        self._bpfo = bpfo

    @property
    def bpfi(self):
        """Gets the bpfi of this BearingResponse.  # noqa: E501


        :return: The bpfi of this BearingResponse.  # noqa: E501
        :rtype: float
        """
        return self._bpfi

    @bpfi.setter
    def bpfi(self, bpfi):
        """Sets the bpfi of this BearingResponse.


        :param bpfi: The bpfi of this BearingResponse.  # noqa: E501
        :type: float
        """
        if bpfi is None:
            raise ValueError("Invalid value for `bpfi`, must not be `None`")  # noqa: E501

        self._bpfi = bpfi

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(BearingResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BearingResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.corporations_api import CorporationsApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestCorporationsApi(unittest.TestCase):
    """CorporationsApi unit test stubs"""

    def setUp(self):
        self.api = CorporationsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_corporation(self):
        """Test case for create_corporation

        Creates a new corporation  # noqa: E501
        """
        pass

    def test_get_corporation(self):
        """Test case for get_corporation

        Returns a single corporation  # noqa: E501
        """
        pass

    def test_get_corporation_roi(self):
        """Test case for get_corporation_roi

        Gets ROI information for a corporation  # noqa: E501
        """
        pass

    def test_get_corporations(self):
        """Test case for get_corporations

        Returns paginated list corporations  # noqa: E501
        """
        pass

    def test_update_corporation(self):
        """Test case for update_corporation

        Updates a Corporation  # noqa: E501
        """
        pass

    def test_upload_corporation_icon(self):
        """Test case for upload_corporation_icon

        Updates a Corporations Icon  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ThermalCameraImageResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'timestamp': 'datetime',
        'image': 'str',
        'thermal_camera_serial_number': 'int'
    }

    attribute_map = {
        'timestamp': 'Timestamp',
        'image': 'Image',
        'thermal_camera_serial_number': 'ThermalCameraSerialNumber'
    }

    def __init__(self, timestamp=None, image=None, thermal_camera_serial_number=None):  # noqa: E501
        """ThermalCameraImageResponse - a model defined in Swagger"""  # noqa: E501
        self._timestamp = None
        self._image = None
        self._thermal_camera_serial_number = None
        self.discriminator = None
        self.timestamp = timestamp
        self.image = image
        self.thermal_camera_serial_number = thermal_camera_serial_number

    @property
    def timestamp(self):
        """Gets the timestamp of this ThermalCameraImageResponse.  # noqa: E501


        :return: The timestamp of this ThermalCameraImageResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this ThermalCameraImageResponse.


        :param timestamp: The timestamp of this ThermalCameraImageResponse.  # noqa: E501
        :type: datetime
        """
        if timestamp is None:
            raise ValueError("Invalid value for `timestamp`, must not be `None`")  # noqa: E501

        self._timestamp = timestamp

    @property
    def image(self):
        """Gets the image of this ThermalCameraImageResponse.  # noqa: E501


        :return: The image of this ThermalCameraImageResponse.  # noqa: E501
        :rtype: str
        """
        return self._image

    @image.setter
    def image(self, image):
        """Sets the image of this ThermalCameraImageResponse.


        :param image: The image of this ThermalCameraImageResponse.  # noqa: E501
        :type: str
        """
        if image is None:
            raise ValueError("Invalid value for `image`, must not be `None`")  # noqa: E501

        self._image = image

    @property
    def thermal_camera_serial_number(self):
        """Gets the thermal_camera_serial_number of this ThermalCameraImageResponse.  # noqa: E501


        :return: The thermal_camera_serial_number of this ThermalCameraImageResponse.  # noqa: E501
        :rtype: int
        """
        return self._thermal_camera_serial_number

    @thermal_camera_serial_number.setter
    def thermal_camera_serial_number(self, thermal_camera_serial_number):
        """Sets the thermal_camera_serial_number of this ThermalCameraImageResponse.


        :param thermal_camera_serial_number: The thermal_camera_serial_number of this ThermalCameraImageResponse.  # noqa: E501
        :type: int
        """
        if thermal_camera_serial_number is None:
            raise ValueError("Invalid value for `thermal_camera_serial_number`, must not be `None`")  # noqa: E501

        self._thermal_camera_serial_number = thermal_camera_serial_number

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ThermalCameraImageResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ThermalCameraImageResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class CurrentUserResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'email': 'str',
        'first_name': 'str',
        'last_name': 'str',
        'phone_number': 'str',
        'application_role': 'UserRoleCodes',
        'accepted_eula': 'bool',
        'corporations': 'list[UserCorporationChild]',
        'locations': 'list[UserLocationChild]',
        'profile': 'ProfileChild'
    }

    attribute_map = {
        'id': 'Id',
        'email': 'Email',
        'first_name': 'FirstName',
        'last_name': 'LastName',
        'phone_number': 'PhoneNumber',
        'application_role': 'ApplicationRole',
        'accepted_eula': 'AcceptedEula',
        'corporations': 'Corporations',
        'locations': 'Locations',
        'profile': 'Profile'
    }

    def __init__(self, id=None, email=None, first_name=None, last_name=None, phone_number=None, application_role=None, accepted_eula=None, corporations=None, locations=None, profile=None):  # noqa: E501
        """CurrentUserResponse - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._email = None
        self._first_name = None
        self._last_name = None
        self._phone_number = None
        self._application_role = None
        self._accepted_eula = None
        self._corporations = None
        self._locations = None
        self._profile = None
        self.discriminator = None
        self.id = id
        self.email = email
        self.first_name = first_name
        self.last_name = last_name
        if phone_number is not None:
            self.phone_number = phone_number
        self.application_role = application_role
        self.accepted_eula = accepted_eula
        self.corporations = corporations
        self.locations = locations
        self.profile = profile

    @property
    def id(self):
        """Gets the id of this CurrentUserResponse.  # noqa: E501

        The current user's unique identifier.  # noqa: E501

        :return: The id of this CurrentUserResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this CurrentUserResponse.

        The current user's unique identifier.  # noqa: E501

        :param id: The id of this CurrentUserResponse.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def email(self):
        """Gets the email of this CurrentUserResponse.  # noqa: E501

        The current user's email address.  # noqa: E501

        :return: The email of this CurrentUserResponse.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this CurrentUserResponse.

        The current user's email address.  # noqa: E501

        :param email: The email of this CurrentUserResponse.  # noqa: E501
        :type: str
        """
        if email is None:
            raise ValueError("Invalid value for `email`, must not be `None`")  # noqa: E501

        self._email = email

    @property
    def first_name(self):
        """Gets the first_name of this CurrentUserResponse.  # noqa: E501

        The current user's first name.  # noqa: E501

        :return: The first_name of this CurrentUserResponse.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this CurrentUserResponse.

        The current user's first name.  # noqa: E501

        :param first_name: The first_name of this CurrentUserResponse.  # noqa: E501
        :type: str
        """
        if first_name is None:
            raise ValueError("Invalid value for `first_name`, must not be `None`")  # noqa: E501

        self._first_name = first_name

    @property
    def last_name(self):
        """Gets the last_name of this CurrentUserResponse.  # noqa: E501

        The current user's last name.  # noqa: E501

        :return: The last_name of this CurrentUserResponse.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this CurrentUserResponse.

        The current user's last name.  # noqa: E501

        :param last_name: The last_name of this CurrentUserResponse.  # noqa: E501
        :type: str
        """
        if last_name is None:
            raise ValueError("Invalid value for `last_name`, must not be `None`")  # noqa: E501

        self._last_name = last_name

    @property
    def phone_number(self):
        """Gets the phone_number of this CurrentUserResponse.  # noqa: E501

        The current user's phone number. May not exist if the user has not set their phone number.  # noqa: E501

        :return: The phone_number of this CurrentUserResponse.  # noqa: E501
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """Sets the phone_number of this CurrentUserResponse.

        The current user's phone number. May not exist if the user has not set their phone number.  # noqa: E501

        :param phone_number: The phone_number of this CurrentUserResponse.  # noqa: E501
        :type: str
        """

        self._phone_number = phone_number

    @property
    def application_role(self):
        """Gets the application_role of this CurrentUserResponse.  # noqa: E501


        :return: The application_role of this CurrentUserResponse.  # noqa: E501
        :rtype: UserRoleCodes
        """
        return self._application_role

    @application_role.setter
    def application_role(self, application_role):
        """Sets the application_role of this CurrentUserResponse.


        :param application_role: The application_role of this CurrentUserResponse.  # noqa: E501
        :type: UserRoleCodes
        """
        if application_role is None:
            raise ValueError("Invalid value for `application_role`, must not be `None`")  # noqa: E501

        self._application_role = application_role

    @property
    def accepted_eula(self):
        """Gets the accepted_eula of this CurrentUserResponse.  # noqa: E501

        The current user's EULA status.  # noqa: E501

        :return: The accepted_eula of this CurrentUserResponse.  # noqa: E501
        :rtype: bool
        """
        return self._accepted_eula

    @accepted_eula.setter
    def accepted_eula(self, accepted_eula):
        """Sets the accepted_eula of this CurrentUserResponse.

        The current user's EULA status.  # noqa: E501

        :param accepted_eula: The accepted_eula of this CurrentUserResponse.  # noqa: E501
        :type: bool
        """
        if accepted_eula is None:
            raise ValueError("Invalid value for `accepted_eula`, must not be `None`")  # noqa: E501

        self._accepted_eula = accepted_eula

    @property
    def corporations(self):
        """Gets the corporations of this CurrentUserResponse.  # noqa: E501

        The current user's assigned corporations. For users with access to all corporations, this will be an empty list.  # noqa: E501

        :return: The corporations of this CurrentUserResponse.  # noqa: E501
        :rtype: list[UserCorporationChild]
        """
        return self._corporations

    @corporations.setter
    def corporations(self, corporations):
        """Sets the corporations of this CurrentUserResponse.

        The current user's assigned corporations. For users with access to all corporations, this will be an empty list.  # noqa: E501

        :param corporations: The corporations of this CurrentUserResponse.  # noqa: E501
        :type: list[UserCorporationChild]
        """
        if corporations is None:
            raise ValueError("Invalid value for `corporations`, must not be `None`")  # noqa: E501

        self._corporations = corporations

    @property
    def locations(self):
        """Gets the locations of this CurrentUserResponse.  # noqa: E501

        The current user's assigned locations. For users with access to all locations, this will be an empty list.  # noqa: E501

        :return: The locations of this CurrentUserResponse.  # noqa: E501
        :rtype: list[UserLocationChild]
        """
        return self._locations

    @locations.setter
    def locations(self, locations):
        """Sets the locations of this CurrentUserResponse.

        The current user's assigned locations. For users with access to all locations, this will be an empty list.  # noqa: E501

        :param locations: The locations of this CurrentUserResponse.  # noqa: E501
        :type: list[UserLocationChild]
        """
        if locations is None:
            raise ValueError("Invalid value for `locations`, must not be `None`")  # noqa: E501

        self._locations = locations

    @property
    def profile(self):
        """Gets the profile of this CurrentUserResponse.  # noqa: E501


        :return: The profile of this CurrentUserResponse.  # noqa: E501
        :rtype: ProfileChild
        """
        return self._profile

    @profile.setter
    def profile(self, profile):
        """Sets the profile of this CurrentUserResponse.


        :param profile: The profile of this CurrentUserResponse.  # noqa: E501
        :type: ProfileChild
        """
        if profile is None:
            raise ValueError("Invalid value for `profile`, must not be `None`")  # noqa: E501

        self._profile = profile

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CurrentUserResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CurrentUserResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class BearingChild(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'bearing_id': 'str',
        'bearing_name': 'str',
        'bearing_manufacturer': 'str',
        'bearing_bpfi': 'float'
    }

    attribute_map = {
        'bearing_id': 'BearingId',
        'bearing_name': 'BearingName',
        'bearing_manufacturer': 'BearingManufacturer',
        'bearing_bpfi': 'BearingBpfi'
    }

    def __init__(self, bearing_id=None, bearing_name=None, bearing_manufacturer=None, bearing_bpfi=None):  # noqa: E501
        """BearingChild - a model defined in Swagger"""  # noqa: E501
        self._bearing_id = None
        self._bearing_name = None
        self._bearing_manufacturer = None
        self._bearing_bpfi = None
        self.discriminator = None
        self.bearing_id = bearing_id
        self.bearing_name = bearing_name
        self.bearing_manufacturer = bearing_manufacturer
        self.bearing_bpfi = bearing_bpfi

    @property
    def bearing_id(self):
        """Gets the bearing_id of this BearingChild.  # noqa: E501


        :return: The bearing_id of this BearingChild.  # noqa: E501
        :rtype: str
        """
        return self._bearing_id

    @bearing_id.setter
    def bearing_id(self, bearing_id):
        """Sets the bearing_id of this BearingChild.


        :param bearing_id: The bearing_id of this BearingChild.  # noqa: E501
        :type: str
        """
        if bearing_id is None:
            raise ValueError("Invalid value for `bearing_id`, must not be `None`")  # noqa: E501

        self._bearing_id = bearing_id

    @property
    def bearing_name(self):
        """Gets the bearing_name of this BearingChild.  # noqa: E501


        :return: The bearing_name of this BearingChild.  # noqa: E501
        :rtype: str
        """
        return self._bearing_name

    @bearing_name.setter
    def bearing_name(self, bearing_name):
        """Sets the bearing_name of this BearingChild.


        :param bearing_name: The bearing_name of this BearingChild.  # noqa: E501
        :type: str
        """
        if bearing_name is None:
            raise ValueError("Invalid value for `bearing_name`, must not be `None`")  # noqa: E501

        self._bearing_name = bearing_name

    @property
    def bearing_manufacturer(self):
        """Gets the bearing_manufacturer of this BearingChild.  # noqa: E501


        :return: The bearing_manufacturer of this BearingChild.  # noqa: E501
        :rtype: str
        """
        return self._bearing_manufacturer

    @bearing_manufacturer.setter
    def bearing_manufacturer(self, bearing_manufacturer):
        """Sets the bearing_manufacturer of this BearingChild.


        :param bearing_manufacturer: The bearing_manufacturer of this BearingChild.  # noqa: E501
        :type: str
        """
        if bearing_manufacturer is None:
            raise ValueError("Invalid value for `bearing_manufacturer`, must not be `None`")  # noqa: E501

        self._bearing_manufacturer = bearing_manufacturer

    @property
    def bearing_bpfi(self):
        """Gets the bearing_bpfi of this BearingChild.  # noqa: E501


        :return: The bearing_bpfi of this BearingChild.  # noqa: E501
        :rtype: float
        """
        return self._bearing_bpfi

    @bearing_bpfi.setter
    def bearing_bpfi(self, bearing_bpfi):
        """Sets the bearing_bpfi of this BearingChild.


        :param bearing_bpfi: The bearing_bpfi of this BearingChild.  # noqa: E501
        :type: float
        """
        if bearing_bpfi is None:
            raise ValueError("Invalid value for `bearing_bpfi`, must not be `None`")  # noqa: E501

        self._bearing_bpfi = bearing_bpfi

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(BearingChild, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BearingChild):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.pictures_api import PicturesApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestPicturesApi(unittest.TestCase):
    """PicturesApi unit test stubs"""

    def setUp(self):
        self.api = PicturesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_assign_pictures_to_group(self):
        """Test case for assign_pictures_to_group

        Associate an ordered list of pictures to a group  # noqa: E501
        """
        pass

    def test_get_picture(self):
        """Test case for get_picture

        Returns a single picture  # noqa: E501
        """
        pass

    def test_get_pictures(self):
        """Test case for get_pictures

        Returns a paged list of all pictures  # noqa: E501
        """
        pass

    def test_get_pictures_for_group(self):
        """Test case for get_pictures_for_group

        Get a paged list of pictures associated with a group  # noqa: E501
        """
        pass

    def test_get_pictures_for_location(self):
        """Test case for get_pictures_for_location

        Returns a paged list of pictures associated with an account  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AlarmDefinitionChild(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'low_alarm_value': 'float',
        'low_warning_value': 'float',
        'high_alarm_value': 'float',
        'high_warning_value': 'float',
        'off_threshold_value': 'float',
        'classification': 'MetricClassificationSourceEnum',
        'classification_indicator_source_id': 'str',
        'notification_criteria_percentage': 'float',
        'notification_criteria_points': 'int',
        'notification_criteria_coefficient': 'float'
    }

    attribute_map = {
        'low_alarm_value': 'LowAlarmValue',
        'low_warning_value': 'LowWarningValue',
        'high_alarm_value': 'HighAlarmValue',
        'high_warning_value': 'HighWarningValue',
        'off_threshold_value': 'OffThresholdValue',
        'classification': 'Classification',
        'classification_indicator_source_id': 'ClassificationIndicatorSourceId',
        'notification_criteria_percentage': 'NotificationCriteriaPercentage',
        'notification_criteria_points': 'NotificationCriteriaPoints',
        'notification_criteria_coefficient': 'NotificationCriteriaCoefficient'
    }

    def __init__(self, low_alarm_value=None, low_warning_value=None, high_alarm_value=None, high_warning_value=None, off_threshold_value=None, classification=None, classification_indicator_source_id=None, notification_criteria_percentage=None, notification_criteria_points=None, notification_criteria_coefficient=None):  # noqa: E501
        """AlarmDefinitionChild - a model defined in Swagger"""  # noqa: E501
        self._low_alarm_value = None
        self._low_warning_value = None
        self._high_alarm_value = None
        self._high_warning_value = None
        self._off_threshold_value = None
        self._classification = None
        self._classification_indicator_source_id = None
        self._notification_criteria_percentage = None
        self._notification_criteria_points = None
        self._notification_criteria_coefficient = None
        self.discriminator = None
        if low_alarm_value is not None:
            self.low_alarm_value = low_alarm_value
        if low_warning_value is not None:
            self.low_warning_value = low_warning_value
        if high_alarm_value is not None:
            self.high_alarm_value = high_alarm_value
        if high_warning_value is not None:
            self.high_warning_value = high_warning_value
        if off_threshold_value is not None:
            self.off_threshold_value = off_threshold_value
        self.classification = classification
        if classification_indicator_source_id is not None:
            self.classification_indicator_source_id = classification_indicator_source_id
        if notification_criteria_percentage is not None:
            self.notification_criteria_percentage = notification_criteria_percentage
        if notification_criteria_points is not None:
            self.notification_criteria_points = notification_criteria_points
        if notification_criteria_coefficient is not None:
            self.notification_criteria_coefficient = notification_criteria_coefficient

    @property
    def low_alarm_value(self):
        """Gets the low_alarm_value of this AlarmDefinitionChild.  # noqa: E501

        When an indicator's current value goes below this threshold, an alarm will be triggered.  # noqa: E501

        :return: The low_alarm_value of this AlarmDefinitionChild.  # noqa: E501
        :rtype: float
        """
        return self._low_alarm_value

    @low_alarm_value.setter
    def low_alarm_value(self, low_alarm_value):
        """Sets the low_alarm_value of this AlarmDefinitionChild.

        When an indicator's current value goes below this threshold, an alarm will be triggered.  # noqa: E501

        :param low_alarm_value: The low_alarm_value of this AlarmDefinitionChild.  # noqa: E501
        :type: float
        """

        self._low_alarm_value = low_alarm_value

    @property
    def low_warning_value(self):
        """Gets the low_warning_value of this AlarmDefinitionChild.  # noqa: E501

        When an indicator's current value goes below this threshold, a warning will be triggered.  # noqa: E501

        :return: The low_warning_value of this AlarmDefinitionChild.  # noqa: E501
        :rtype: float
        """
        return self._low_warning_value

    @low_warning_value.setter
    def low_warning_value(self, low_warning_value):
        """Sets the low_warning_value of this AlarmDefinitionChild.

        When an indicator's current value goes below this threshold, a warning will be triggered.  # noqa: E501

        :param low_warning_value: The low_warning_value of this AlarmDefinitionChild.  # noqa: E501
        :type: float
        """

        self._low_warning_value = low_warning_value

    @property
    def high_alarm_value(self):
        """Gets the high_alarm_value of this AlarmDefinitionChild.  # noqa: E501

        When an indicator's current value goes above this threshold, an alarm will be triggered.  # noqa: E501

        :return: The high_alarm_value of this AlarmDefinitionChild.  # noqa: E501
        :rtype: float
        """
        return self._high_alarm_value

    @high_alarm_value.setter
    def high_alarm_value(self, high_alarm_value):
        """Sets the high_alarm_value of this AlarmDefinitionChild.

        When an indicator's current value goes above this threshold, an alarm will be triggered.  # noqa: E501

        :param high_alarm_value: The high_alarm_value of this AlarmDefinitionChild.  # noqa: E501
        :type: float
        """

        self._high_alarm_value = high_alarm_value

    @property
    def high_warning_value(self):
        """Gets the high_warning_value of this AlarmDefinitionChild.  # noqa: E501

        When an indicator's current value goes above this threshold, a warning will be triggered.  # noqa: E501

        :return: The high_warning_value of this AlarmDefinitionChild.  # noqa: E501
        :rtype: float
        """
        return self._high_warning_value

    @high_warning_value.setter
    def high_warning_value(self, high_warning_value):
        """Sets the high_warning_value of this AlarmDefinitionChild.

        When an indicator's current value goes above this threshold, a warning will be triggered.  # noqa: E501

        :param high_warning_value: The high_warning_value of this AlarmDefinitionChild.  # noqa: E501
        :type: float
        """

        self._high_warning_value = high_warning_value

    @property
    def off_threshold_value(self):
        """Gets the off_threshold_value of this AlarmDefinitionChild.  # noqa: E501

        When an indicator's current value is below this threshold, the associated machine/asset will be considered  as turned off (not currently running).  # noqa: E501

        :return: The off_threshold_value of this AlarmDefinitionChild.  # noqa: E501
        :rtype: float
        """
        return self._off_threshold_value

    @off_threshold_value.setter
    def off_threshold_value(self, off_threshold_value):
        """Sets the off_threshold_value of this AlarmDefinitionChild.

        When an indicator's current value is below this threshold, the associated machine/asset will be considered  as turned off (not currently running).  # noqa: E501

        :param off_threshold_value: The off_threshold_value of this AlarmDefinitionChild.  # noqa: E501
        :type: float
        """

        self._off_threshold_value = off_threshold_value

    @property
    def classification(self):
        """Gets the classification of this AlarmDefinitionChild.  # noqa: E501


        :return: The classification of this AlarmDefinitionChild.  # noqa: E501
        :rtype: MetricClassificationSourceEnum
        """
        return self._classification

    @classification.setter
    def classification(self, classification):
        """Sets the classification of this AlarmDefinitionChild.


        :param classification: The classification of this AlarmDefinitionChild.  # noqa: E501
        :type: MetricClassificationSourceEnum
        """
        if classification is None:
            raise ValueError("Invalid value for `classification`, must not be `None`")  # noqa: E501

        self._classification = classification

    @property
    def classification_indicator_source_id(self):
        """Gets the classification_indicator_source_id of this AlarmDefinitionChild.  # noqa: E501

        If the off threshold classification is inherited, this is the parent indicator ID that it is inherited from.  # noqa: E501

        :return: The classification_indicator_source_id of this AlarmDefinitionChild.  # noqa: E501
        :rtype: str
        """
        return self._classification_indicator_source_id

    @classification_indicator_source_id.setter
    def classification_indicator_source_id(self, classification_indicator_source_id):
        """Sets the classification_indicator_source_id of this AlarmDefinitionChild.

        If the off threshold classification is inherited, this is the parent indicator ID that it is inherited from.  # noqa: E501

        :param classification_indicator_source_id: The classification_indicator_source_id of this AlarmDefinitionChild.  # noqa: E501
        :type: str
        """

        self._classification_indicator_source_id = classification_indicator_source_id

    @property
    def notification_criteria_percentage(self):
        """Gets the notification_criteria_percentage of this AlarmDefinitionChild.  # noqa: E501

        Notification criteria percentage of the alarm child  # noqa: E501

        :return: The notification_criteria_percentage of this AlarmDefinitionChild.  # noqa: E501
        :rtype: float
        """
        return self._notification_criteria_percentage

    @notification_criteria_percentage.setter
    def notification_criteria_percentage(self, notification_criteria_percentage):
        """Sets the notification_criteria_percentage of this AlarmDefinitionChild.

        Notification criteria percentage of the alarm child  # noqa: E501

        :param notification_criteria_percentage: The notification_criteria_percentage of this AlarmDefinitionChild.  # noqa: E501
        :type: float
        """

        self._notification_criteria_percentage = notification_criteria_percentage

    @property
    def notification_criteria_points(self):
        """Gets the notification_criteria_points of this AlarmDefinitionChild.  # noqa: E501

        Notification criteria points of the alarm child  # noqa: E501

        :return: The notification_criteria_points of this AlarmDefinitionChild.  # noqa: E501
        :rtype: int
        """
        return self._notification_criteria_points

    @notification_criteria_points.setter
    def notification_criteria_points(self, notification_criteria_points):
        """Sets the notification_criteria_points of this AlarmDefinitionChild.

        Notification criteria points of the alarm child  # noqa: E501

        :param notification_criteria_points: The notification_criteria_points of this AlarmDefinitionChild.  # noqa: E501
        :type: int
        """

        self._notification_criteria_points = notification_criteria_points

    @property
    def notification_criteria_coefficient(self):
        """Gets the notification_criteria_coefficient of this AlarmDefinitionChild.  # noqa: E501


        :return: The notification_criteria_coefficient of this AlarmDefinitionChild.  # noqa: E501
        :rtype: float
        """
        return self._notification_criteria_coefficient

    @notification_criteria_coefficient.setter
    def notification_criteria_coefficient(self, notification_criteria_coefficient):
        """Sets the notification_criteria_coefficient of this AlarmDefinitionChild.


        :param notification_criteria_coefficient: The notification_criteria_coefficient of this AlarmDefinitionChild.  # noqa: E501
        :type: float
        """

        self._notification_criteria_coefficient = notification_criteria_coefficient

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AlarmDefinitionChild, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AlarmDefinitionChild):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class BulletinResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'title': 'str',
        'description': 'str',
        'start': 'datetime',
        'end': 'datetime',
        'article_url': 'str',
        'image_file_name': 'str',
        'thumbnail_file_name': 'str',
        'is_draft': 'bool'
    }

    attribute_map = {
        'id': 'Id',
        'title': 'Title',
        'description': 'Description',
        'start': 'Start',
        'end': 'End',
        'article_url': 'ArticleUrl',
        'image_file_name': 'ImageFileName',
        'thumbnail_file_name': 'ThumbnailFileName',
        'is_draft': 'IsDraft'
    }

    def __init__(self, id=None, title=None, description=None, start=None, end=None, article_url=None, image_file_name=None, thumbnail_file_name=None, is_draft=None):  # noqa: E501
        """BulletinResponse - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._title = None
        self._description = None
        self._start = None
        self._end = None
        self._article_url = None
        self._image_file_name = None
        self._thumbnail_file_name = None
        self._is_draft = None
        self.discriminator = None
        self.id = id
        self.title = title
        if description is not None:
            self.description = description
        if start is not None:
            self.start = start
        if end is not None:
            self.end = end
        if article_url is not None:
            self.article_url = article_url
        self.image_file_name = image_file_name
        self.thumbnail_file_name = thumbnail_file_name
        self.is_draft = is_draft

    @property
    def id(self):
        """Gets the id of this BulletinResponse.  # noqa: E501

        Id of the bulletin  # noqa: E501

        :return: The id of this BulletinResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BulletinResponse.

        Id of the bulletin  # noqa: E501

        :param id: The id of this BulletinResponse.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def title(self):
        """Gets the title of this BulletinResponse.  # noqa: E501

        The title of the bulletin  # noqa: E501

        :return: The title of this BulletinResponse.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this BulletinResponse.

        The title of the bulletin  # noqa: E501

        :param title: The title of this BulletinResponse.  # noqa: E501
        :type: str
        """
        if title is None:
            raise ValueError("Invalid value for `title`, must not be `None`")  # noqa: E501

        self._title = title

    @property
    def description(self):
        """Gets the description of this BulletinResponse.  # noqa: E501

        Bulletin description  # noqa: E501

        :return: The description of this BulletinResponse.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this BulletinResponse.

        Bulletin description  # noqa: E501

        :param description: The description of this BulletinResponse.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def start(self):
        """Gets the start of this BulletinResponse.  # noqa: E501

        The date/time when the bulletin is to become active  # noqa: E501

        :return: The start of this BulletinResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._start

    @start.setter
    def start(self, start):
        """Sets the start of this BulletinResponse.

        The date/time when the bulletin is to become active  # noqa: E501

        :param start: The start of this BulletinResponse.  # noqa: E501
        :type: datetime
        """

        self._start = start

    @property
    def end(self):
        """Gets the end of this BulletinResponse.  # noqa: E501

        The date/time when the bulletin is to become inactive  # noqa: E501

        :return: The end of this BulletinResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._end

    @end.setter
    def end(self, end):
        """Sets the end of this BulletinResponse.

        The date/time when the bulletin is to become inactive  # noqa: E501

        :param end: The end of this BulletinResponse.  # noqa: E501
        :type: datetime
        """

        self._end = end

    @property
    def article_url(self):
        """Gets the article_url of this BulletinResponse.  # noqa: E501

        Link to article associated with bulletin  # noqa: E501

        :return: The article_url of this BulletinResponse.  # noqa: E501
        :rtype: str
        """
        return self._article_url

    @article_url.setter
    def article_url(self, article_url):
        """Sets the article_url of this BulletinResponse.

        Link to article associated with bulletin  # noqa: E501

        :param article_url: The article_url of this BulletinResponse.  # noqa: E501
        :type: str
        """

        self._article_url = article_url

    @property
    def image_file_name(self):
        """Gets the image_file_name of this BulletinResponse.  # noqa: E501

        File name of the bulletin's image  # noqa: E501

        :return: The image_file_name of this BulletinResponse.  # noqa: E501
        :rtype: str
        """
        return self._image_file_name

    @image_file_name.setter
    def image_file_name(self, image_file_name):
        """Sets the image_file_name of this BulletinResponse.

        File name of the bulletin's image  # noqa: E501

        :param image_file_name: The image_file_name of this BulletinResponse.  # noqa: E501
        :type: str
        """
        if image_file_name is None:
            raise ValueError("Invalid value for `image_file_name`, must not be `None`")  # noqa: E501

        self._image_file_name = image_file_name

    @property
    def thumbnail_file_name(self):
        """Gets the thumbnail_file_name of this BulletinResponse.  # noqa: E501

        File name of the thumbnail of the bulletin's image  # noqa: E501

        :return: The thumbnail_file_name of this BulletinResponse.  # noqa: E501
        :rtype: str
        """
        return self._thumbnail_file_name

    @thumbnail_file_name.setter
    def thumbnail_file_name(self, thumbnail_file_name):
        """Sets the thumbnail_file_name of this BulletinResponse.

        File name of the thumbnail of the bulletin's image  # noqa: E501

        :param thumbnail_file_name: The thumbnail_file_name of this BulletinResponse.  # noqa: E501
        :type: str
        """
        if thumbnail_file_name is None:
            raise ValueError("Invalid value for `thumbnail_file_name`, must not be `None`")  # noqa: E501

        self._thumbnail_file_name = thumbnail_file_name

    @property
    def is_draft(self):
        """Gets the is_draft of this BulletinResponse.  # noqa: E501

        If the bulletin is in 'draft mode.' A draft bulletin is not  considered active, even if the current time  falls between Prometheus.Core.Dto.Billboards.BulletinResponse.Start and Prometheus.Core.Dto.Billboards.BulletinResponse.End  # noqa: E501

        :return: The is_draft of this BulletinResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_draft

    @is_draft.setter
    def is_draft(self, is_draft):
        """Sets the is_draft of this BulletinResponse.

        If the bulletin is in 'draft mode.' A draft bulletin is not  considered active, even if the current time  falls between Prometheus.Core.Dto.Billboards.BulletinResponse.Start and Prometheus.Core.Dto.Billboards.BulletinResponse.End  # noqa: E501

        :param is_draft: The is_draft of this BulletinResponse.  # noqa: E501
        :type: bool
        """
        if is_draft is None:
            raise ValueError("Invalid value for `is_draft`, must not be `None`")  # noqa: E501

        self._is_draft = is_draft

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(BulletinResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BulletinResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.markers_api import MarkersApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestMarkersApi(unittest.TestCase):
    """MarkersApi unit test stubs"""

    def setUp(self):
        self.api = MarkersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_marker(self):
        """Test case for create_marker

        Creates a new Marker for an asset  # noqa: E501
        """
        pass

    def test_delete_marker(self):
        """Test case for delete_marker

        Deletes the specified Marker  # noqa: E501
        """
        pass

    def test_get_marker(self):
        """Test case for get_marker

        Gets the specified marker  # noqa: E501
        """
        pass

    def test_update_marker(self):
        """Test case for update_marker

        Updates the specified Marker  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AssetEconomicsChild(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'asset_cost': 'float',
        'date_installed': 'datetime',
        'annual_run_time': 'float',
        'lost_production_cost': 'float',
        'overhaul_cost': 'float',
        'power_consumption': 'float',
        'life_expectancy': 'float',
        'unscheduled_downtime': 'float'
    }

    attribute_map = {
        'asset_cost': 'AssetCost',
        'date_installed': 'DateInstalled',
        'annual_run_time': 'AnnualRunTime',
        'lost_production_cost': 'LostProductionCost',
        'overhaul_cost': 'OverhaulCost',
        'power_consumption': 'PowerConsumption',
        'life_expectancy': 'LifeExpectancy',
        'unscheduled_downtime': 'UnscheduledDowntime'
    }

    def __init__(self, asset_cost=None, date_installed=None, annual_run_time=None, lost_production_cost=None, overhaul_cost=None, power_consumption=None, life_expectancy=None, unscheduled_downtime=None):  # noqa: E501
        """AssetEconomicsChild - a model defined in Swagger"""  # noqa: E501
        self._asset_cost = None
        self._date_installed = None
        self._annual_run_time = None
        self._lost_production_cost = None
        self._overhaul_cost = None
        self._power_consumption = None
        self._life_expectancy = None
        self._unscheduled_downtime = None
        self.discriminator = None
        if asset_cost is not None:
            self.asset_cost = asset_cost
        if date_installed is not None:
            self.date_installed = date_installed
        if annual_run_time is not None:
            self.annual_run_time = annual_run_time
        if lost_production_cost is not None:
            self.lost_production_cost = lost_production_cost
        if overhaul_cost is not None:
            self.overhaul_cost = overhaul_cost
        if power_consumption is not None:
            self.power_consumption = power_consumption
        if life_expectancy is not None:
            self.life_expectancy = life_expectancy
        if unscheduled_downtime is not None:
            self.unscheduled_downtime = unscheduled_downtime

    @property
    def asset_cost(self):
        """Gets the asset_cost of this AssetEconomicsChild.  # noqa: E501


        :return: The asset_cost of this AssetEconomicsChild.  # noqa: E501
        :rtype: float
        """
        return self._asset_cost

    @asset_cost.setter
    def asset_cost(self, asset_cost):
        """Sets the asset_cost of this AssetEconomicsChild.


        :param asset_cost: The asset_cost of this AssetEconomicsChild.  # noqa: E501
        :type: float
        """

        self._asset_cost = asset_cost

    @property
    def date_installed(self):
        """Gets the date_installed of this AssetEconomicsChild.  # noqa: E501


        :return: The date_installed of this AssetEconomicsChild.  # noqa: E501
        :rtype: datetime
        """
        return self._date_installed

    @date_installed.setter
    def date_installed(self, date_installed):
        """Sets the date_installed of this AssetEconomicsChild.


        :param date_installed: The date_installed of this AssetEconomicsChild.  # noqa: E501
        :type: datetime
        """

        self._date_installed = date_installed

    @property
    def annual_run_time(self):
        """Gets the annual_run_time of this AssetEconomicsChild.  # noqa: E501


        :return: The annual_run_time of this AssetEconomicsChild.  # noqa: E501
        :rtype: float
        """
        return self._annual_run_time

    @annual_run_time.setter
    def annual_run_time(self, annual_run_time):
        """Sets the annual_run_time of this AssetEconomicsChild.


        :param annual_run_time: The annual_run_time of this AssetEconomicsChild.  # noqa: E501
        :type: float
        """

        self._annual_run_time = annual_run_time

    @property
    def lost_production_cost(self):
        """Gets the lost_production_cost of this AssetEconomicsChild.  # noqa: E501


        :return: The lost_production_cost of this AssetEconomicsChild.  # noqa: E501
        :rtype: float
        """
        return self._lost_production_cost

    @lost_production_cost.setter
    def lost_production_cost(self, lost_production_cost):
        """Sets the lost_production_cost of this AssetEconomicsChild.


        :param lost_production_cost: The lost_production_cost of this AssetEconomicsChild.  # noqa: E501
        :type: float
        """

        self._lost_production_cost = lost_production_cost

    @property
    def overhaul_cost(self):
        """Gets the overhaul_cost of this AssetEconomicsChild.  # noqa: E501


        :return: The overhaul_cost of this AssetEconomicsChild.  # noqa: E501
        :rtype: float
        """
        return self._overhaul_cost

    @overhaul_cost.setter
    def overhaul_cost(self, overhaul_cost):
        """Sets the overhaul_cost of this AssetEconomicsChild.


        :param overhaul_cost: The overhaul_cost of this AssetEconomicsChild.  # noqa: E501
        :type: float
        """

        self._overhaul_cost = overhaul_cost

    @property
    def power_consumption(self):
        """Gets the power_consumption of this AssetEconomicsChild.  # noqa: E501


        :return: The power_consumption of this AssetEconomicsChild.  # noqa: E501
        :rtype: float
        """
        return self._power_consumption

    @power_consumption.setter
    def power_consumption(self, power_consumption):
        """Sets the power_consumption of this AssetEconomicsChild.


        :param power_consumption: The power_consumption of this AssetEconomicsChild.  # noqa: E501
        :type: float
        """

        self._power_consumption = power_consumption

    @property
    def life_expectancy(self):
        """Gets the life_expectancy of this AssetEconomicsChild.  # noqa: E501


        :return: The life_expectancy of this AssetEconomicsChild.  # noqa: E501
        :rtype: float
        """
        return self._life_expectancy

    @life_expectancy.setter
    def life_expectancy(self, life_expectancy):
        """Sets the life_expectancy of this AssetEconomicsChild.


        :param life_expectancy: The life_expectancy of this AssetEconomicsChild.  # noqa: E501
        :type: float
        """

        self._life_expectancy = life_expectancy

    @property
    def unscheduled_downtime(self):
        """Gets the unscheduled_downtime of this AssetEconomicsChild.  # noqa: E501


        :return: The unscheduled_downtime of this AssetEconomicsChild.  # noqa: E501
        :rtype: float
        """
        return self._unscheduled_downtime

    @unscheduled_downtime.setter
    def unscheduled_downtime(self, unscheduled_downtime):
        """Sets the unscheduled_downtime of this AssetEconomicsChild.


        :param unscheduled_downtime: The unscheduled_downtime of this AssetEconomicsChild.  # noqa: E501
        :type: float
        """

        self._unscheduled_downtime = unscheduled_downtime

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AssetEconomicsChild, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AssetEconomicsChild):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ScheduledReportSubscriptionResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'report_type': 'ScheduledReportType',
        'interval_type': 'ScheduledReportSubscriptionIntervalType',
        'created_by': 'CreatedByUserChild',
        'location': 'LocationChild',
        'corporation': 'CorporationChild',
        'users': 'list[UserChild]'
    }

    attribute_map = {
        'id': 'Id',
        'report_type': 'ReportType',
        'interval_type': 'IntervalType',
        'created_by': 'CreatedBy',
        'location': 'Location',
        'corporation': 'Corporation',
        'users': 'Users'
    }

    def __init__(self, id=None, report_type=None, interval_type=None, created_by=None, location=None, corporation=None, users=None):  # noqa: E501
        """ScheduledReportSubscriptionResponse - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._report_type = None
        self._interval_type = None
        self._created_by = None
        self._location = None
        self._corporation = None
        self._users = None
        self.discriminator = None
        self.id = id
        self.report_type = report_type
        self.interval_type = interval_type
        self.created_by = created_by
        self.location = location
        self.corporation = corporation
        self.users = users

    @property
    def id(self):
        """Gets the id of this ScheduledReportSubscriptionResponse.  # noqa: E501

        The Id of the scheduled subscription  # noqa: E501

        :return: The id of this ScheduledReportSubscriptionResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ScheduledReportSubscriptionResponse.

        The Id of the scheduled subscription  # noqa: E501

        :param id: The id of this ScheduledReportSubscriptionResponse.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def report_type(self):
        """Gets the report_type of this ScheduledReportSubscriptionResponse.  # noqa: E501


        :return: The report_type of this ScheduledReportSubscriptionResponse.  # noqa: E501
        :rtype: ScheduledReportType
        """
        return self._report_type

    @report_type.setter
    def report_type(self, report_type):
        """Sets the report_type of this ScheduledReportSubscriptionResponse.


        :param report_type: The report_type of this ScheduledReportSubscriptionResponse.  # noqa: E501
        :type: ScheduledReportType
        """
        if report_type is None:
            raise ValueError("Invalid value for `report_type`, must not be `None`")  # noqa: E501

        self._report_type = report_type

    @property
    def interval_type(self):
        """Gets the interval_type of this ScheduledReportSubscriptionResponse.  # noqa: E501


        :return: The interval_type of this ScheduledReportSubscriptionResponse.  # noqa: E501
        :rtype: ScheduledReportSubscriptionIntervalType
        """
        return self._interval_type

    @interval_type.setter
    def interval_type(self, interval_type):
        """Sets the interval_type of this ScheduledReportSubscriptionResponse.


        :param interval_type: The interval_type of this ScheduledReportSubscriptionResponse.  # noqa: E501
        :type: ScheduledReportSubscriptionIntervalType
        """
        if interval_type is None:
            raise ValueError("Invalid value for `interval_type`, must not be `None`")  # noqa: E501

        self._interval_type = interval_type

    @property
    def created_by(self):
        """Gets the created_by of this ScheduledReportSubscriptionResponse.  # noqa: E501


        :return: The created_by of this ScheduledReportSubscriptionResponse.  # noqa: E501
        :rtype: CreatedByUserChild
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this ScheduledReportSubscriptionResponse.


        :param created_by: The created_by of this ScheduledReportSubscriptionResponse.  # noqa: E501
        :type: CreatedByUserChild
        """
        if created_by is None:
            raise ValueError("Invalid value for `created_by`, must not be `None`")  # noqa: E501

        self._created_by = created_by

    @property
    def location(self):
        """Gets the location of this ScheduledReportSubscriptionResponse.  # noqa: E501


        :return: The location of this ScheduledReportSubscriptionResponse.  # noqa: E501
        :rtype: LocationChild
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this ScheduledReportSubscriptionResponse.


        :param location: The location of this ScheduledReportSubscriptionResponse.  # noqa: E501
        :type: LocationChild
        """
        if location is None:
            raise ValueError("Invalid value for `location`, must not be `None`")  # noqa: E501

        self._location = location

    @property
    def corporation(self):
        """Gets the corporation of this ScheduledReportSubscriptionResponse.  # noqa: E501


        :return: The corporation of this ScheduledReportSubscriptionResponse.  # noqa: E501
        :rtype: CorporationChild
        """
        return self._corporation

    @corporation.setter
    def corporation(self, corporation):
        """Sets the corporation of this ScheduledReportSubscriptionResponse.


        :param corporation: The corporation of this ScheduledReportSubscriptionResponse.  # noqa: E501
        :type: CorporationChild
        """
        if corporation is None:
            raise ValueError("Invalid value for `corporation`, must not be `None`")  # noqa: E501

        self._corporation = corporation

    @property
    def users(self):
        """Gets the users of this ScheduledReportSubscriptionResponse.  # noqa: E501

        A list of users subscribed to the report  # noqa: E501

        :return: The users of this ScheduledReportSubscriptionResponse.  # noqa: E501
        :rtype: list[UserChild]
        """
        return self._users

    @users.setter
    def users(self, users):
        """Sets the users of this ScheduledReportSubscriptionResponse.

        A list of users subscribed to the report  # noqa: E501

        :param users: The users of this ScheduledReportSubscriptionResponse.  # noqa: E501
        :type: list[UserChild]
        """
        if users is None:
            raise ValueError("Invalid value for `users`, must not be `None`")  # noqa: E501

        self._users = users

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ScheduledReportSubscriptionResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ScheduledReportSubscriptionResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AssetCategoryParameterChild(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'valid_values': 'list[str]',
        'code': 'str',
        'name': 'str',
        'category_parameter_type': 'AssetCategoryParameterType',
        'min_value': 'float',
        'min_value_inclusive': 'bool',
        'max_value': 'float',
        'max_value_inclusive': 'bool',
        'default_value': 'str'
    }

    attribute_map = {
        'valid_values': 'ValidValues',
        'code': 'Code',
        'name': 'Name',
        'category_parameter_type': 'CategoryParameterType',
        'min_value': 'MinValue',
        'min_value_inclusive': 'MinValueInclusive',
        'max_value': 'MaxValue',
        'max_value_inclusive': 'MaxValueInclusive',
        'default_value': 'DefaultValue'
    }

    def __init__(self, valid_values=None, code=None, name=None, category_parameter_type=None, min_value=None, min_value_inclusive=None, max_value=None, max_value_inclusive=None, default_value=None):  # noqa: E501
        """AssetCategoryParameterChild - a model defined in Swagger"""  # noqa: E501
        self._valid_values = None
        self._code = None
        self._name = None
        self._category_parameter_type = None
        self._min_value = None
        self._min_value_inclusive = None
        self._max_value = None
        self._max_value_inclusive = None
        self._default_value = None
        self.discriminator = None
        if valid_values is not None:
            self.valid_values = valid_values
        self.code = code
        self.name = name
        self.category_parameter_type = category_parameter_type
        if min_value is not None:
            self.min_value = min_value
        if min_value_inclusive is not None:
            self.min_value_inclusive = min_value_inclusive
        if max_value is not None:
            self.max_value = max_value
        if max_value_inclusive is not None:
            self.max_value_inclusive = max_value_inclusive
        if default_value is not None:
            self.default_value = default_value

    @property
    def valid_values(self):
        """Gets the valid_values of this AssetCategoryParameterChild.  # noqa: E501


        :return: The valid_values of this AssetCategoryParameterChild.  # noqa: E501
        :rtype: list[str]
        """
        return self._valid_values

    @valid_values.setter
    def valid_values(self, valid_values):
        """Sets the valid_values of this AssetCategoryParameterChild.


        :param valid_values: The valid_values of this AssetCategoryParameterChild.  # noqa: E501
        :type: list[str]
        """

        self._valid_values = valid_values

    @property
    def code(self):
        """Gets the code of this AssetCategoryParameterChild.  # noqa: E501


        :return: The code of this AssetCategoryParameterChild.  # noqa: E501
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this AssetCategoryParameterChild.


        :param code: The code of this AssetCategoryParameterChild.  # noqa: E501
        :type: str
        """
        if code is None:
            raise ValueError("Invalid value for `code`, must not be `None`")  # noqa: E501

        self._code = code

    @property
    def name(self):
        """Gets the name of this AssetCategoryParameterChild.  # noqa: E501


        :return: The name of this AssetCategoryParameterChild.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AssetCategoryParameterChild.


        :param name: The name of this AssetCategoryParameterChild.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def category_parameter_type(self):
        """Gets the category_parameter_type of this AssetCategoryParameterChild.  # noqa: E501


        :return: The category_parameter_type of this AssetCategoryParameterChild.  # noqa: E501
        :rtype: AssetCategoryParameterType
        """
        return self._category_parameter_type

    @category_parameter_type.setter
    def category_parameter_type(self, category_parameter_type):
        """Sets the category_parameter_type of this AssetCategoryParameterChild.


        :param category_parameter_type: The category_parameter_type of this AssetCategoryParameterChild.  # noqa: E501
        :type: AssetCategoryParameterType
        """
        if category_parameter_type is None:
            raise ValueError("Invalid value for `category_parameter_type`, must not be `None`")  # noqa: E501

        self._category_parameter_type = category_parameter_type

    @property
    def min_value(self):
        """Gets the min_value of this AssetCategoryParameterChild.  # noqa: E501


        :return: The min_value of this AssetCategoryParameterChild.  # noqa: E501
        :rtype: float
        """
        return self._min_value

    @min_value.setter
    def min_value(self, min_value):
        """Sets the min_value of this AssetCategoryParameterChild.


        :param min_value: The min_value of this AssetCategoryParameterChild.  # noqa: E501
        :type: float
        """

        self._min_value = min_value

    @property
    def min_value_inclusive(self):
        """Gets the min_value_inclusive of this AssetCategoryParameterChild.  # noqa: E501


        :return: The min_value_inclusive of this AssetCategoryParameterChild.  # noqa: E501
        :rtype: bool
        """
        return self._min_value_inclusive

    @min_value_inclusive.setter
    def min_value_inclusive(self, min_value_inclusive):
        """Sets the min_value_inclusive of this AssetCategoryParameterChild.


        :param min_value_inclusive: The min_value_inclusive of this AssetCategoryParameterChild.  # noqa: E501
        :type: bool
        """

        self._min_value_inclusive = min_value_inclusive

    @property
    def max_value(self):
        """Gets the max_value of this AssetCategoryParameterChild.  # noqa: E501


        :return: The max_value of this AssetCategoryParameterChild.  # noqa: E501
        :rtype: float
        """
        return self._max_value

    @max_value.setter
    def max_value(self, max_value):
        """Sets the max_value of this AssetCategoryParameterChild.


        :param max_value: The max_value of this AssetCategoryParameterChild.  # noqa: E501
        :type: float
        """

        self._max_value = max_value

    @property
    def max_value_inclusive(self):
        """Gets the max_value_inclusive of this AssetCategoryParameterChild.  # noqa: E501


        :return: The max_value_inclusive of this AssetCategoryParameterChild.  # noqa: E501
        :rtype: bool
        """
        return self._max_value_inclusive

    @max_value_inclusive.setter
    def max_value_inclusive(self, max_value_inclusive):
        """Sets the max_value_inclusive of this AssetCategoryParameterChild.


        :param max_value_inclusive: The max_value_inclusive of this AssetCategoryParameterChild.  # noqa: E501
        :type: bool
        """

        self._max_value_inclusive = max_value_inclusive

    @property
    def default_value(self):
        """Gets the default_value of this AssetCategoryParameterChild.  # noqa: E501


        :return: The default_value of this AssetCategoryParameterChild.  # noqa: E501
        :rtype: str
        """
        return self._default_value

    @default_value.setter
    def default_value(self, default_value):
        """Sets the default_value of this AssetCategoryParameterChild.


        :param default_value: The default_value of this AssetCategoryParameterChild.  # noqa: E501
        :type: str
        """

        self._default_value = default_value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AssetCategoryParameterChild, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AssetCategoryParameterChild):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class TicketResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'number': 'int',
        'name': 'str',
        'description': 'str',
        'created': 'datetime',
        'updated': 'datetime',
        'archived': 'datetime',
        'is_archived': 'bool',
        'board': 'BoardChild',
        'location': 'LocationChild',
        'created_by': 'UserChild',
        'status': 'StatusChild',
        'assets': 'list[GroupChild]'
    }

    attribute_map = {
        'id': 'Id',
        'number': 'Number',
        'name': 'Name',
        'description': 'Description',
        'created': 'Created',
        'updated': 'Updated',
        'archived': 'Archived',
        'is_archived': 'IsArchived',
        'board': 'Board',
        'location': 'Location',
        'created_by': 'CreatedBy',
        'status': 'Status',
        'assets': 'Assets'
    }

    def __init__(self, id=None, number=None, name=None, description=None, created=None, updated=None, archived=None, is_archived=None, board=None, location=None, created_by=None, status=None, assets=None):  # noqa: E501
        """TicketResponse - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._number = None
        self._name = None
        self._description = None
        self._created = None
        self._updated = None
        self._archived = None
        self._is_archived = None
        self._board = None
        self._location = None
        self._created_by = None
        self._status = None
        self._assets = None
        self.discriminator = None
        self.id = id
        self.number = number
        self.name = name
        if description is not None:
            self.description = description
        self.created = created
        self.updated = updated
        if archived is not None:
            self.archived = archived
        self.is_archived = is_archived
        self.board = board
        self.location = location
        self.created_by = created_by
        self.status = status
        self.assets = assets

    @property
    def id(self):
        """Gets the id of this TicketResponse.  # noqa: E501

        Ticket id  # noqa: E501

        :return: The id of this TicketResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this TicketResponse.

        Ticket id  # noqa: E501

        :param id: The id of this TicketResponse.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def number(self):
        """Gets the number of this TicketResponse.  # noqa: E501

        Ticket number  # noqa: E501

        :return: The number of this TicketResponse.  # noqa: E501
        :rtype: int
        """
        return self._number

    @number.setter
    def number(self, number):
        """Sets the number of this TicketResponse.

        Ticket number  # noqa: E501

        :param number: The number of this TicketResponse.  # noqa: E501
        :type: int
        """
        if number is None:
            raise ValueError("Invalid value for `number`, must not be `None`")  # noqa: E501

        self._number = number

    @property
    def name(self):
        """Gets the name of this TicketResponse.  # noqa: E501

        Ticket name  # noqa: E501

        :return: The name of this TicketResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this TicketResponse.

        Ticket name  # noqa: E501

        :param name: The name of this TicketResponse.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def description(self):
        """Gets the description of this TicketResponse.  # noqa: E501

        Ticket description  # noqa: E501

        :return: The description of this TicketResponse.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this TicketResponse.

        Ticket description  # noqa: E501

        :param description: The description of this TicketResponse.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def created(self):
        """Gets the created of this TicketResponse.  # noqa: E501

        When the ticket was created  # noqa: E501

        :return: The created of this TicketResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this TicketResponse.

        When the ticket was created  # noqa: E501

        :param created: The created of this TicketResponse.  # noqa: E501
        :type: datetime
        """
        if created is None:
            raise ValueError("Invalid value for `created`, must not be `None`")  # noqa: E501

        self._created = created

    @property
    def updated(self):
        """Gets the updated of this TicketResponse.  # noqa: E501

        When the ticket was updated  # noqa: E501

        :return: The updated of this TicketResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._updated

    @updated.setter
    def updated(self, updated):
        """Sets the updated of this TicketResponse.

        When the ticket was updated  # noqa: E501

        :param updated: The updated of this TicketResponse.  # noqa: E501
        :type: datetime
        """
        if updated is None:
            raise ValueError("Invalid value for `updated`, must not be `None`")  # noqa: E501

        self._updated = updated

    @property
    def archived(self):
        """Gets the archived of this TicketResponse.  # noqa: E501

        When the ticket was archived. Will be null if the ticket  has not been archived.  # noqa: E501

        :return: The archived of this TicketResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._archived

    @archived.setter
    def archived(self, archived):
        """Sets the archived of this TicketResponse.

        When the ticket was archived. Will be null if the ticket  has not been archived.  # noqa: E501

        :param archived: The archived of this TicketResponse.  # noqa: E501
        :type: datetime
        """

        self._archived = archived

    @property
    def is_archived(self):
        """Gets the is_archived of this TicketResponse.  # noqa: E501

        Whether the ticket is archived.  # noqa: E501

        :return: The is_archived of this TicketResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_archived

    @is_archived.setter
    def is_archived(self, is_archived):
        """Sets the is_archived of this TicketResponse.

        Whether the ticket is archived.  # noqa: E501

        :param is_archived: The is_archived of this TicketResponse.  # noqa: E501
        :type: bool
        """
        if is_archived is None:
            raise ValueError("Invalid value for `is_archived`, must not be `None`")  # noqa: E501

        self._is_archived = is_archived

    @property
    def board(self):
        """Gets the board of this TicketResponse.  # noqa: E501


        :return: The board of this TicketResponse.  # noqa: E501
        :rtype: BoardChild
        """
        return self._board

    @board.setter
    def board(self, board):
        """Sets the board of this TicketResponse.


        :param board: The board of this TicketResponse.  # noqa: E501
        :type: BoardChild
        """
        if board is None:
            raise ValueError("Invalid value for `board`, must not be `None`")  # noqa: E501

        self._board = board

    @property
    def location(self):
        """Gets the location of this TicketResponse.  # noqa: E501


        :return: The location of this TicketResponse.  # noqa: E501
        :rtype: LocationChild
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this TicketResponse.


        :param location: The location of this TicketResponse.  # noqa: E501
        :type: LocationChild
        """
        if location is None:
            raise ValueError("Invalid value for `location`, must not be `None`")  # noqa: E501

        self._location = location

    @property
    def created_by(self):
        """Gets the created_by of this TicketResponse.  # noqa: E501


        :return: The created_by of this TicketResponse.  # noqa: E501
        :rtype: UserChild
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this TicketResponse.


        :param created_by: The created_by of this TicketResponse.  # noqa: E501
        :type: UserChild
        """
        if created_by is None:
            raise ValueError("Invalid value for `created_by`, must not be `None`")  # noqa: E501

        self._created_by = created_by

    @property
    def status(self):
        """Gets the status of this TicketResponse.  # noqa: E501


        :return: The status of this TicketResponse.  # noqa: E501
        :rtype: StatusChild
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this TicketResponse.


        :param status: The status of this TicketResponse.  # noqa: E501
        :type: StatusChild
        """
        if status is None:
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501

        self._status = status

    @property
    def assets(self):
        """Gets the assets of this TicketResponse.  # noqa: E501

        The assets associated with the ticket  # noqa: E501

        :return: The assets of this TicketResponse.  # noqa: E501
        :rtype: list[GroupChild]
        """
        return self._assets

    @assets.setter
    def assets(self, assets):
        """Sets the assets of this TicketResponse.

        The assets associated with the ticket  # noqa: E501

        :param assets: The assets of this TicketResponse.  # noqa: E501
        :type: list[GroupChild]
        """
        if assets is None:
            raise ValueError("Invalid value for `assets`, must not be `None`")  # noqa: E501

        self._assets = assets

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TicketResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TicketResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
